Rvoterdistance-package: Rvoterdistance: Voter Distance to Polling Locations

Rvoterdistance-packageR Documentation

Rvoterdistance: Voter Distance to Polling Locations

Description

Calculates the distance between each voter in a voter file (given lat/long coordinates or sf point geometries) and multiple polling or vote-by-mail drop box locations. Returns nearest location, k-nearest locations, or all locations within a distance threshold. Core computation uses the Haversine formula implemented in C++ via 'Rcpp'.

Author(s)

Maintainer: Loren Collingwood lcollingwood@unm.edu

See Also

Useful links:


Rvoterdistance documentation built on May 28, 2026, 1:06 a.m.