| dbox | R Documentation |
A data frame of ballot drop box locations in King County, Washington.
dbox
A data frame with columns including lat and long.
King County Elections
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.