| Rvoterdistance-package | R Documentation |
Calculates the distance between each voter in a voter file (given lat/long coordinates or sf point geometries) and multiple polling or vote-by-mail drop box locations. Returns nearest location, k-nearest locations, or all locations within a distance threshold. Core computation uses the Haversine formula implemented in C++ via 'Rcpp'.
Maintainer: Loren Collingwood lcollingwood@unm.edu
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.