Learn R Programming

Rvoterdistance (version 1.1)

Rvoterdistance-package:

Description

This package is designed to calculate the distance between each voter in a voter file -- given lat/long coordinates -- and many potential (early) polling or vote by mail drop box locations, then return the minimum distance.

Arguments

Details

See demo(demo, "Rvoterdistance") for examples on how to use the code